@@ -60,7 +60,7 @@ namespace pika::bulk_detail {
         static constexpr bool sends_done = false;
 
         friend constexpr decltype(auto) tag_invoke(
-            pika::execution::experimental::get_env_t, bulk_sender_type const& s)
+            pika::execution::experimental::get_env_t, bulk_sender_type const& s) noexcept
         {
             return pika::execution::experimental::get_env(s.sender);
         }
