@@ -77,8 +77,6 @@ int main()
         PIKA_TEST(!tag_invoke_overload_called);
     }
 
-    // Piping into start_detached is not allowed according to the specification.
-#if !defined(PIKA_HAVE_STDEXEC)
     // operator| overload
     {
         std::atomic<bool> start_called{false};
@@ -89,7 +87,6 @@ int main()
         PIKA_TEST(connect_called);
         PIKA_TEST(!tag_invoke_overload_called);
     }
-#endif
 
     // tag_invoke overload
     {
