@@ -8,7 +8,6 @@
 #include <pika/execution_base/any_sender.hpp>
 #include <pika/execution_base/sender.hpp>
 #include <pika/functional/bind_front.hpp>
-#include <pika/functional/invoke_fused.hpp>
 #include <pika/modules/errors.hpp>
 #include <pika/testing.hpp>
 
@@ -78,9 +77,8 @@ struct non_copyable_sender
 
         friend void tag_invoke(pika::execution::experimental::start_t, operation_state& os) noexcept
         {
-            pika::util::detail::invoke_fused(
-                pika::util::detail::bind_front(
-                    pika::execution::experimental::set_value, std::move(os.r)),
+            std::apply(pika::util::detail::bind_front(
+                           pika::execution::experimental::set_value, std::move(os.r)),
                 std::move(os.ts));
         };
     };
@@ -134,9 +132,8 @@ struct sender
 
         friend void tag_invoke(pika::execution::experimental::start_t, operation_state& os) noexcept
         {
-            pika::util::detail::invoke_fused(
-                pika::util::detail::bind_front(
-                    pika::execution::experimental::set_value, std::move(os.r)),
+            std::apply(pika::util::detail::bind_front(
+                           pika::execution::experimental::set_value, std::move(os.r)),
                 std::move(os.ts));
         };
     };
@@ -631,13 +628,49 @@ void test_globals()
 
 void test_empty_any_sender()
 {
-    ex::unique_any_sender<> uas{};
-    ex::any_sender<> as{};
+    {
+        ex::unique_any_sender<> uas{};
+        ex::any_sender<> as{};
 
-    PIKA_TEST(uas.empty());
-    PIKA_TEST(!uas);
-    PIKA_TEST(as.empty());
-    PIKA_TEST(!as);
+        PIKA_TEST(uas.empty());
+        PIKA_TEST(!uas);
+        PIKA_TEST(as.empty());
+        PIKA_TEST(!as);
+    }
+
+    {
+        ex::unique_any_sender<> uas{ex::just()};
+        ex::any_sender<> as{ex::just()};
+
+        PIKA_TEST(!uas.empty());
+        PIKA_TEST(uas);
+        PIKA_TEST(!as.empty());
+        PIKA_TEST(as);
+
+        uas.reset(ex::just());
+        as.reset(ex::just());
+
+        PIKA_TEST(!uas.empty());
+        PIKA_TEST(uas);
+        PIKA_TEST(!as.empty());
+        PIKA_TEST(as);
+
+        uas.reset();
+        as.reset();
+
+        PIKA_TEST(uas.empty());
+        PIKA_TEST(!uas);
+        PIKA_TEST(as.empty());
+        PIKA_TEST(!as);
+
+        uas.reset(ex::unique_any_sender<>{});
+        as.reset(ex::any_sender<>{});
+
+        PIKA_TEST(uas.empty());
+        PIKA_TEST(!uas);
+        PIKA_TEST(as.empty());
+        PIKA_TEST(!as);
+    }
 }
 
 void test_make_any_sender()
