@@ -231,7 +231,8 @@ namespace pika::execution::experimental {
                 }
             };
 
-            friend env tag_invoke(pika::execution::experimental::get_env_t, sender const& s)
+            friend env tag_invoke(
+                pika::execution::experimental::get_env_t, sender const& s) noexcept
             {
                 return {s.scheduler};
             }
