@@ -173,8 +173,7 @@ namespace pika::thread_pool_bulk_detail {
                         std::advance(it, i_begin);
                         for (std::uint32_t i = i_begin; i < i_end; ++i)
                         {
-                            pika::util::detail::invoke_fused(
-                                pika::util::detail::bind_front(op_state->f, *it), ts);
+                            std::apply(pika::util::detail::bind_front(op_state->f, *it), ts);
                             ++it;
                         }
                     }
@@ -231,7 +230,7 @@ namespace pika::thread_pool_bulk_detail {
                             !std::is_same_v<std::decay_t<Ts>, pika::detail::monostate>>>
                     void operator()(Ts&& ts) const
                     {
-                        pika::util::detail::invoke_fused(
+                        std::apply(
                             pika::util::detail::bind_front(pika::execution::experimental::set_value,
                                 PIKA_MOVE(op_state->receiver)),
                             PIKA_FORWARD(Ts, ts));
