@@ -151,7 +151,7 @@ void test_sender_receiver_then_wait()
     });
     tt::sync_wait(std::move(work2));
 
-    PIKA_TEST_EQ(then_count, std::size_t(2));
+    PIKA_TEST_EQ(then_count.load(), std::size_t(2));
     PIKA_TEST(executed);
 }
 
@@ -169,7 +169,7 @@ void test_sender_receiver_then_sync_wait()
         return 42;
     });
     auto result = tt::sync_wait(std::move(work));
-    PIKA_TEST_EQ(then_count, std::size_t(1));
+    PIKA_TEST_EQ(then_count.load(), std::size_t(1));
     static_assert(
         std::is_same<int, std::decay_t<decltype(result)>>::value, "result should be an int");
     PIKA_TEST_EQ(result, 42);
@@ -199,7 +199,7 @@ void test_sender_receiver_then_arguments()
         return 2 * s.size();
     });
     auto result = tt::sync_wait(std::move(work3));
-    PIKA_TEST_EQ(then_count, std::size_t(3));
+    PIKA_TEST_EQ(then_count.load(), std::size_t(3));
     static_assert(std::is_same<std::size_t, std::decay_t<decltype(result)>>::value,
         "result should be a std::size_t");
     PIKA_TEST_EQ(result, std::size_t(12));
@@ -556,27 +556,16 @@ void test_when_all_vector()
 
         auto when1 = ex::when_all_vector(std::move(senders));
 
-#if !defined(PIKA_HAVE_STDEXEC)
         bool executed{false};
-#endif
-        tt::sync_wait(std::move(when1)
-        // TODO: ADL issues? Uncommenting instantiates set_value with the
-        // sync_wait_receiver from when_all_vector_receiver, i.e. then is
-        // "skipped".
-#if !defined(PIKA_HAVE_STDEXEC)
-            | ex::then([parent_id, &executed](std::vector<double> v) {
-                  PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
-                  PIKA_TEST_EQ(v.size(), std::size_t(3));
-                  PIKA_TEST_EQ(v[0], 42.0);
-                  PIKA_TEST_EQ(v[1], 43.0);
-                  PIKA_TEST_EQ(v[2], 3.14);
-                  executed = true;
-              })
-#endif
-        );
-#if !defined(PIKA_HAVE_STDEXEC)
+        tt::sync_wait(std::move(when1) | ex::then([parent_id, &executed](std::vector<double> v) {
+            PIKA_TEST_NEQ(parent_id, std::this_thread::get_id());
+            PIKA_TEST_EQ(v.size(), std::size_t(3));
+            PIKA_TEST_EQ(v[0], 42.0);
+            PIKA_TEST_EQ(v[1], 43.0);
+            PIKA_TEST_EQ(v[2], 3.14);
+            executed = true;
+        }));
         PIKA_TEST(executed);
-#endif
     }
 
     {
@@ -601,14 +590,8 @@ void test_when_all_vector()
 
         try
         {
-            tt::sync_wait(ex::when_all_vector(std::move(senders))
-            // TODO: ADL issues? Uncommenting instantiates set_value with the
-            // sync_wait_receiver from when_all_vector_receiver, i.e. then is
-            // "skipped".
-#if !defined(PIKA_HAVE_STDEXEC)
-                | ex::then([](std::vector<int>) { PIKA_TEST(false); })
-#endif
-            );
+            tt::sync_wait(ex::when_all_vector(std::move(senders)) |
+                ex::then([](std::vector<int>) { PIKA_TEST(false); }));
             PIKA_TEST(false);
         }
         catch (std::runtime_error const& e)
@@ -642,14 +625,8 @@ void test_when_all_vector()
 
         try
         {
-            tt::sync_wait(ex::when_all_vector(std::move(senders))
-            // TODO: ADL issues? Uncommenting instantiates set_value with the
-            // sync_wait_receiver from when_all_vector_receiver, i.e. then is
-            // "skipped".
-#if !defined(PIKA_HAVE_STDEXEC)
-                | ex::then([](std::vector<int>) { PIKA_TEST(false); })
-#endif
-            );
+            tt::sync_wait(ex::when_all_vector(std::move(senders)) |
+                ex::then([](std::vector<int>) { PIKA_TEST(false); }));
             PIKA_TEST(false);
         }
         catch (std::runtime_error const& e)
@@ -680,8 +657,6 @@ void test_ensure_started()
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
 
-    // TODO: The split sender in stdexec is not copyable.
-#if !defined(PIKA_HAVE_STDEXEC)
     {
         auto s = ex::transfer_just(sched, 42) | ex::ensure_started() | ex::split();
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
@@ -689,7 +664,6 @@ void test_ensure_started()
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
-#endif
 
     // It's allowed to discard the sender from ensure_started
     {
@@ -699,8 +673,6 @@ void test_ensure_started()
 
 void test_ensure_started_when_all()
 {
-    // TODO: The split sender in stdexec is not copyable.
-#if !defined(PIKA_HAVE_STDEXEC)
     ex::std_thread_scheduler sched{};
 
     {
@@ -731,8 +703,8 @@ void test_ensure_started_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             3);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -753,7 +725,7 @@ void test_ensure_started_when_all()
             std::unique_lock l{mtx};
             cond.wait(l, [&]() { return started; });
         }
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
         auto succ1 = s | ex::then([&](int const& x) {
             ++successor_task_calls;
             return x + 1;
@@ -765,8 +737,8 @@ void test_ensure_started_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -798,16 +770,13 @@ void test_ensure_started_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
-#endif
 }
 
 void test_split()
 {
-    // TODO: No default implementation in stdexec.
-#if !defined(PIKA_HAVE_STDEXEC)
     ex::std_thread_scheduler sched{};
 
     {
@@ -831,13 +800,10 @@ void test_split()
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
-#endif
 }
 
 void test_split_when_all()
 {
-    // TODO: No default implementation in stdexec.
-#if !defined(PIKA_HAVE_STDEXEC)
     ex::std_thread_scheduler sched{};
 
     {
@@ -855,8 +821,8 @@ void test_split_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             3);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -877,8 +843,8 @@ void test_split_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -899,10 +865,9 @@ void test_split_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
-#endif
 }
 
 void test_let_value()
@@ -1150,8 +1115,6 @@ void test_detach()
 
 void test_bulk()
 {
-    // TODO: No default implementation in stdexec.
-#if !defined(PIKA_HAVE_STDEXEC)
     std::vector<int> const ns = {0, 1, 10, 43};
 
     for (int n : ns)
@@ -1187,6 +1150,8 @@ void test_bulk()
         }
     }
 
+    // The specification only allows integral shapes
+#if !defined(PIKA_HAVE_STDEXEC)
     {
         std::unordered_set<std::string> string_map;
         std::vector<std::string> v = {"hello", "brave", "new", "world"};
@@ -1205,6 +1170,7 @@ void test_bulk()
             PIKA_TEST(string_map.find(s) != string_map.end());
         }
     }
+#endif
 
     for (auto n : ns)
     {
@@ -1250,7 +1216,6 @@ void test_bulk()
             }
         }
     }
-#endif
 }
 
 void test_completion_scheduler()
@@ -1282,7 +1247,6 @@ void test_completion_scheduler()
             "the completion scheduler should be a std_thread_scheduler");
     }
 
-#if !defined(PIKA_HAVE_STDEXEC)
     {
         auto sender = ex::bulk(ex::schedule(ex::std_thread_scheduler{}), 10, [](int) {});
         auto completion_scheduler =
@@ -1313,7 +1277,6 @@ void test_completion_scheduler()
             std::is_same_v<std::decay_t<decltype(completion_scheduler)>, ex::std_thread_scheduler>,
             "the completion scheduler should be a std_thread_scheduler");
     }
-#endif
 }
 
 void test_scheduler_queries()
