@@ -158,7 +158,7 @@ void test_sender_receiver_then_wait()
     });
     tt::sync_wait(std::move(work2));
 
-    PIKA_TEST_EQ(then_count, std::size_t(2));
+    PIKA_TEST_EQ(then_count.load(), std::size_t(2));
     PIKA_TEST(executed);
 }
 
@@ -176,7 +176,7 @@ void test_sender_receiver_then_sync_wait()
         return 42;
     });
     auto result = tt::sync_wait(std::move(work));
-    PIKA_TEST_EQ(then_count, std::size_t(1));
+    PIKA_TEST_EQ(then_count.load(), std::size_t(1));
     static_assert(
         std::is_same<int, std::decay_t<decltype(result)>>::value, "result should be an int");
     PIKA_TEST_EQ(result, 42);
@@ -206,7 +206,7 @@ void test_sender_receiver_then_arguments()
         return 2 * s.size();
     });
     auto result = tt::sync_wait(std::move(work3));
-    PIKA_TEST_EQ(then_count, std::size_t(3));
+    PIKA_TEST_EQ(then_count.load(), std::size_t(3));
     static_assert(std::is_same<std::size_t, std::decay_t<decltype(result)>>::value,
         "result should be a std::size_t");
     PIKA_TEST_EQ(result, std::size_t(12));
@@ -654,27 +654,16 @@ void test_when_all_vector()
 
         auto when1 = ex::when_all_vector(std::move(senders));
 
-#if !defined(PIKA_HAVE_STDEXEC)
         bool executed{false};
-#endif
-        tt::sync_wait(std::move(when1)
-        // TODO: ADL issues? Uncommenting instantiates set_value with the
-        // sync_wait_receiver from when_all_vector_receiver, i.e. then is
-        // "skipped".
-#if !defined(PIKA_HAVE_STDEXEC)
-            | ex::then([parent_id, &executed](std::vector<double> v) {
-                  PIKA_TEST_NEQ(parent_id, pika::this_thread::get_id());
-                  PIKA_TEST_EQ(v.size(), std::size_t(3));
-                  PIKA_TEST_EQ(v[0], 42.0);
-                  PIKA_TEST_EQ(v[1], 43.0);
-                  PIKA_TEST_EQ(v[2], 3.14);
-                  executed = true;
-              })
-#endif
-        );
-#if !defined(PIKA_HAVE_STDEXEC)
+        tt::sync_wait(std::move(when1) | ex::then([parent_id, &executed](std::vector<double> v) {
+            PIKA_TEST_NEQ(parent_id, pika::this_thread::get_id());
+            PIKA_TEST_EQ(v.size(), std::size_t(3));
+            PIKA_TEST_EQ(v[0], 42.0);
+            PIKA_TEST_EQ(v[1], 43.0);
+            PIKA_TEST_EQ(v[2], 3.14);
+            executed = true;
+        }));
         PIKA_TEST(executed);
-#endif
     }
 
     {
@@ -699,14 +688,8 @@ void test_when_all_vector()
 
         try
         {
-            tt::sync_wait(ex::when_all_vector(std::move(senders))
-            // TODO: ADL issues? Uncommenting instantiates set_value with the
-            // sync_wait_receiver from when_all_vector_receiver, i.e. then is
-            // "skipped".
-#if !defined(PIKA_HAVE_STDEXEC)
-                | ex::then([](std::vector<int>) { PIKA_TEST(false); })
-#endif
-            );
+            tt::sync_wait(ex::when_all_vector(std::move(senders)) |
+                ex::then([](std::vector<int>) { PIKA_TEST(false); }));
             PIKA_TEST(false);
         }
         catch (std::runtime_error const& e)
@@ -740,14 +723,8 @@ void test_when_all_vector()
 
         try
         {
-            tt::sync_wait(ex::when_all_vector(std::move(senders))
-            // TODO: ADL issues? Uncommenting instantiates set_value with the
-            // sync_wait_receiver from when_all_vector_receiver, i.e. then is
-            // "skipped".
-#if !defined(PIKA_HAVE_STDEXEC)
-                | ex::then([](std::vector<int>) { PIKA_TEST(false); })
-#endif
-            );
+            tt::sync_wait(ex::when_all_vector(std::move(senders)) |
+                ex::then([](std::vector<int>) { PIKA_TEST(false); }));
             PIKA_TEST(false);
         }
         catch (std::runtime_error const& e)
@@ -839,7 +816,7 @@ void test_future_sender()
         tt::sync_wait(sf);
         tt::sync_wait(sf);
         tt::sync_wait(std::move(sf));
-        PIKA_TEST_EQ(calls, std::size_t(1));
+        PIKA_TEST_EQ(calls.load(), std::size_t(1));
 
         bool exception_thrown = false;
         try
@@ -867,7 +844,7 @@ void test_future_sender()
         PIKA_TEST_EQ(tt::sync_wait(sf), 42);
         PIKA_TEST_EQ(tt::sync_wait(sf), 42);
         PIKA_TEST_EQ(tt::sync_wait(std::move(sf)), 42);
-        PIKA_TEST_EQ(calls, std::size_t(1));
+        PIKA_TEST_EQ(calls.load(), std::size_t(1));
 
         bool exception_thrown = false;
         try
@@ -971,8 +948,6 @@ void test_ensure_started()
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
 
-    // TODO: The split sender in the stdexec is not copyable.
-#if !defined(PIKA_HAVE_STDEXEC)
     {
         auto s = ex::transfer_just(sched, 42) | ex::ensure_started() | ex::split();
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
@@ -980,7 +955,6 @@ void test_ensure_started()
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
-#endif
 
     // It's allowed to discard the sender from ensure_started
     {
@@ -990,8 +964,6 @@ void test_ensure_started()
 
 void test_ensure_started_when_all()
 {
-    // TODO: The split sender in the stdexec is not copyable.
-#if !defined(PIKA_HAVE_STDEXEC)
     ex::thread_pool_scheduler sched{};
 
     {
@@ -1022,8 +994,8 @@ void test_ensure_started_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             3);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -1044,7 +1016,7 @@ void test_ensure_started_when_all()
             std::unique_lock l{mtx};
             cond.wait(l, [&]() { return started; });
         }
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
         auto succ1 = s | ex::then([&](int const& x) {
             ++successor_task_calls;
             return x + 1;
@@ -1056,8 +1028,8 @@ void test_ensure_started_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -1089,16 +1061,13 @@ void test_ensure_started_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
-#endif
 }
 
 void test_split()
 {
-    // TODO: No default implementation in stdexec.
-#if !defined(PIKA_HAVE_STDEXEC)
     ex::thread_pool_scheduler sched{};
 
     {
@@ -1122,13 +1091,10 @@ void test_split()
         PIKA_TEST_EQ(tt::sync_wait(s), 42);
         PIKA_TEST_EQ(tt::sync_wait(std::move(s)), 42);
     }
-#endif
 }
 
 void test_split_when_all()
 {
-    // TODO: No default implementation in stdexec.
-#if !defined(PIKA_HAVE_STDEXEC)
     ex::thread_pool_scheduler sched{};
 
     {
@@ -1146,8 +1112,8 @@ void test_split_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             3);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -1168,8 +1134,8 @@ void test_split_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
 
     {
@@ -1190,10 +1156,9 @@ void test_split_when_all()
         PIKA_TEST_EQ(tt::sync_wait(ex::when_all(succ1, succ2) |
                          ex::then([](int const& x, int const& y) { return x + y; })),
             9);
-        PIKA_TEST_EQ(first_task_calls, std::size_t(1));
-        PIKA_TEST_EQ(successor_task_calls, std::size_t(2));
+        PIKA_TEST_EQ(first_task_calls.load(), std::size_t(1));
+        PIKA_TEST_EQ(successor_task_calls.load(), std::size_t(2));
     }
-#endif
 }
 
 void test_let_value()
@@ -1544,7 +1509,7 @@ void test_keep_future_sender()
         tt::sync_wait(sf | ex::keep_future());
         tt::sync_wait(sf | ex::keep_future());
         tt::sync_wait(std::move(sf) | ex::keep_future());
-        PIKA_TEST_EQ(calls, std::size_t(1));
+        PIKA_TEST_EQ(calls.load(), std::size_t(1));
 
         bool exception_thrown = false;
         try
@@ -1569,7 +1534,7 @@ void test_keep_future_sender()
         PIKA_TEST_EQ(tt::sync_wait(sf | ex::keep_future()).get(), 42);
         PIKA_TEST_EQ(tt::sync_wait(sf | ex::keep_future()).get(), 42);
         PIKA_TEST_EQ(tt::sync_wait(std::move(sf) | ex::keep_future()).get(), 42);
-        PIKA_TEST_EQ(calls, std::size_t(1));
+        PIKA_TEST_EQ(calls.load(), std::size_t(1));
 
         bool exception_thrown = false;
         try
