@@ -9,8 +9,8 @@
 
 #include <pika/config.hpp>
 #if !defined(PIKA_COMPUTE_DEVICE_CODE)
-#include <pika/future.hpp>
-#include <pika/unwrap.hpp>
+# include <pika/future.hpp>
+# include <pika/unwrap.hpp>
 
 // define large action
 double func(double x1, double, double, double, double, double, double)
@@ -21,7 +21,6 @@ double func(double x1, double, double, double, double, double, double)
 int main(int argc, char* argv[])
 {
     pika::shared_future<double> f = pika::make_ready_future(1.0);
-    f = pika::dataflow(
-        pika::launch::sync, pika::unwrapping(&func), f, f, f, f, f, f, f);
+    f = pika::dataflow(pika::launch::sync, pika::unwrapping(&func), f, f, f, f, f, f, f);
 }
 #endif
