@@ -465,12 +465,12 @@ void test_shared_future_for_string()
     PIKA_TEST_EQ(res, "foo");
 }
 
-pika::spinlock callback_mutex;
+pika::concurrency::detail::spinlock callback_mutex;
 unsigned callback_called = 0;
 
 void wait_callback(pika::shared_future<int>)
 {
-    std::lock_guard<pika::spinlock> lk(callback_mutex);
+    std::lock_guard<pika::concurrency::detail::spinlock> lk(callback_mutex);
     ++callback_called;
 }
 
@@ -509,7 +509,7 @@ void test_wait_callback()
 
 void do_nothing_callback(pika::lcos::local::promise<int>& /*pi*/)
 {
-    std::lock_guard<pika::spinlock> lk(callback_mutex);
+    std::lock_guard<pika::concurrency::detail::spinlock> lk(callback_mutex);
     ++callback_called;
 }
 
