@@ -115,11 +115,11 @@ void function_pointers()
     PIKA_TEST_EQ(f3.get(), 163);
     PIKA_TEST_EQ(f4.get(), 10 * 84);
     PIKA_TEST_EQ(f5.get(), 126);
-    PIKA_TEST_EQ(void_f_count, 1u);
-    PIKA_TEST_EQ(int_f_count, 1u);
-    PIKA_TEST_EQ(void_f1_count, 1u);
-    PIKA_TEST_EQ(int_f1_count, 16u);
-    PIKA_TEST_EQ(int_f2_count, 1u);
+    PIKA_TEST_EQ(void_f_count.load(), 1u);
+    PIKA_TEST_EQ(int_f_count.load(), 1u);
+    PIKA_TEST_EQ(void_f1_count.load(), 1u);
+    PIKA_TEST_EQ(int_f1_count.load(), 16u);
+    PIKA_TEST_EQ(int_f2_count.load(), 1u);
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -184,7 +184,7 @@ void future_function_pointers()
 
     f1.wait();
 
-    PIKA_TEST_EQ(future_void_f1_count, 2u);
+    PIKA_TEST_EQ(future_void_f1_count.load(), 2u);
     future_void_f1_count.store(0);
 
     future<void> f2 =
@@ -192,23 +192,23 @@ void future_function_pointers()
             async(&future_void_sf1, shared_future<void>(make_ready_future())));
 
     f2.wait();
-    PIKA_TEST_EQ(future_void_f1_count, 2u);
-    PIKA_TEST_EQ(future_void_f2_count, 1u);
+    PIKA_TEST_EQ(future_void_f1_count.load(), 2u);
+    PIKA_TEST_EQ(future_void_f2_count.load(), 1u);
     future_void_f1_count.store(0);
     future_void_f2_count.store(0);
 
     future<int> f3 = dataflow(&future_int_f1, make_ready_future());
 
     PIKA_TEST_EQ(f3.get(), 1);
-    PIKA_TEST_EQ(future_int_f1_count, 1u);
+    PIKA_TEST_EQ(future_int_f1_count.load(), 1u);
     future_int_f1_count.store(0);
 
     future<int> f4 = dataflow(&future_int_f2, dataflow(&future_int_f1, make_ready_future()),
         dataflow(&future_int_f1, make_ready_future()));
 
     PIKA_TEST_EQ(f4.get(), 2);
-    PIKA_TEST_EQ(future_int_f1_count, 2u);
-    PIKA_TEST_EQ(future_int_f2_count, 1u);
+    PIKA_TEST_EQ(future_int_f1_count.load(), 2u);
+    PIKA_TEST_EQ(future_int_f2_count.load(), 1u);
     future_int_f1_count.store(0);
     future_int_f2_count.store(0);
 
@@ -260,10 +260,10 @@ void plain_arguments()
         future<int> f2 = dataflow(&int_f4, 42);
 
         f1.wait();
-        PIKA_TEST_EQ(void_f4_count, 1u);
+        PIKA_TEST_EQ(void_f4_count.load(), 1u);
 
         PIKA_TEST_EQ(f2.get(), 84);
-        PIKA_TEST_EQ(int_f4_count, 1u);
+        PIKA_TEST_EQ(int_f4_count.load(), 1u);
     }
 
     {
@@ -271,10 +271,10 @@ void plain_arguments()
         future<int> f2 = dataflow(pika::launch::async, &int_f4, 42);
 
         f1.wait();
-        PIKA_TEST_EQ(void_f4_count, 2u);
+        PIKA_TEST_EQ(void_f4_count.load(), 2u);
 
         PIKA_TEST_EQ(f2.get(), 84);
-        PIKA_TEST_EQ(int_f4_count, 2u);
+        PIKA_TEST_EQ(int_f4_count.load(), 2u);
     }
 
     void_f5_count.store(0);
@@ -285,10 +285,10 @@ void plain_arguments()
         future<int> f2 = dataflow(&int_f5, 42, async(&int_f));
 
         f1.wait();
-        PIKA_TEST_EQ(void_f5_count, 1u);
+        PIKA_TEST_EQ(void_f5_count.load(), 1u);
 
         PIKA_TEST_EQ(f2.get(), 126);
-        PIKA_TEST_EQ(int_f5_count, 1u);
+        PIKA_TEST_EQ(int_f5_count.load(), 1u);
     }
 
     {
@@ -296,10 +296,10 @@ void plain_arguments()
         future<int> f2 = dataflow(pika::launch::async, &int_f5, 42, async(&int_f));
 
         f1.wait();
-        PIKA_TEST_EQ(void_f5_count, 2u);
+        PIKA_TEST_EQ(void_f5_count.load(), 2u);
 
         PIKA_TEST_EQ(f2.get(), 126);
-        PIKA_TEST_EQ(int_f5_count, 2u);
+        PIKA_TEST_EQ(int_f5_count.load(), 2u);
     }
 }
 
@@ -313,10 +313,10 @@ void plain_deferred_arguments()
         future<int> f2 = dataflow(pika::launch::deferred, &int_f4, 42);
 
         f1.wait();
-        PIKA_TEST_EQ(void_f4_count, 1u);
+        PIKA_TEST_EQ(void_f4_count.load(), 1u);
 
         PIKA_TEST_EQ(f2.get(), 84);
-        PIKA_TEST_EQ(int_f4_count, 1u);
+        PIKA_TEST_EQ(int_f4_count.load(), 1u);
     }
 
     void_f5_count.store(0);
@@ -327,10 +327,10 @@ void plain_deferred_arguments()
         future<int> f2 = dataflow(&int_f5, 42, async(pika::launch::deferred, &int_f));
 
         f1.wait();
-        PIKA_TEST_EQ(void_f5_count, 1u);
+        PIKA_TEST_EQ(void_f5_count.load(), 1u);
 
         PIKA_TEST_EQ(f2.get(), 126);
-        PIKA_TEST_EQ(int_f5_count, 1u);
+        PIKA_TEST_EQ(int_f5_count.load(), 1u);
     }
 }
 
@@ -346,10 +346,10 @@ void plain_arguments_lazy()
         future<int> f2 = dataflow(policy1, &int_f4, 42);
 
         f1.wait();
-        PIKA_TEST_EQ(void_f4_count, 1u);
+        PIKA_TEST_EQ(void_f4_count.load(), 1u);
 
         PIKA_TEST_EQ(f2.get(), 84);
-        PIKA_TEST_EQ(int_f4_count, 1u);
+        PIKA_TEST_EQ(int_f4_count.load(), 1u);
     }
 
     auto policy2 = pika::launch::select([]() { return pika::launch::async; });
@@ -359,10 +359,10 @@ void plain_arguments_lazy()
         future<int> f2 = dataflow(policy2, &int_f4, 42);
 
         f1.wait();
-        PIKA_TEST_EQ(void_f4_count, 2u);
+        PIKA_TEST_EQ(void_f4_count.load(), 2u);
 
         PIKA_TEST_EQ(f2.get(), 84);
-        PIKA_TEST_EQ(int_f4_count, 2u);
+        PIKA_TEST_EQ(int_f4_count.load(), 2u);
     }
 
     void_f5_count.store(0);
@@ -380,10 +380,10 @@ void plain_arguments_lazy()
         future<int> f2 = dataflow(policy3, &int_f5, 42, async(&int_f));
 
         f1.wait();
-        PIKA_TEST_EQ(void_f5_count, 1u);
+        PIKA_TEST_EQ(void_f5_count.load(), 1u);
 
         PIKA_TEST_EQ(f2.get(), 126);
-        PIKA_TEST_EQ(int_f5_count, 1u);
+        PIKA_TEST_EQ(int_f5_count.load(), 1u);
     }
 }
 
