@@ -464,12 +464,19 @@ static void test_strategic_traverse()
     {
         std::unique_ptr<int> ptr(new int(7));
 
+#if defined(PIKA_GCC_VERSION) && PIKA_GCC_VERSION >= 130000
+# pragma GCC diagnostic push
+# pragma GCC diagnostic ignored "-Wdangling-reference"
+#endif
         std::unique_ptr<int> const& ref = map_pack(
             [](std::unique_ptr<int> const& ref) -> std::unique_ptr<int> const& {
                 // ...
                 return ref;
             },
             ptr);
+#if defined(PIKA_GCC_VERSION) && PIKA_GCC_VERSION >= 130000
+# pragma GCC diagnostic pop
+#endif
 
         PIKA_TEST_EQ(*ref, 7);
         *ptr = 0;
