@@ -7,24 +7,24 @@
 
 #include <pika/config.hpp>
 #if !defined(PIKA_COMPUTE_DEVICE_CODE)
-#include <pika/execution.hpp>
-#include <pika/init.hpp>
-#include <pika/modules/resource_partitioner.hpp>
-#include <pika/modules/thread_pools.hpp>
-#include <pika/modules/topology.hpp>
-#include <pika/runtime.hpp>
+# include <pika/execution.hpp>
+# include <pika/init.hpp>
+# include <pika/modules/resource_partitioner.hpp>
+# include <pika/modules/thread_pools.hpp>
+# include <pika/modules/topology.hpp>
+# include <pika/runtime.hpp>
 
-#include <cmath>
-#include <cstddef>
-#include <cstdint>
-#include <iostream>
-#include <memory>
-#include <set>
-#include <string>
-#include <utility>
-#include <vector>
+# include <cmath>
+# include <cstddef>
+# include <cstdint>
+# include <iostream>
+# include <memory>
+# include <set>
+# include <string>
+# include <utility>
+# include <vector>
 
-#include "system_characteristics.hpp"
+# include "system_characteristics.hpp"
 
 // ------------------------------------------------------------------------
 static bool use_pools = false;
@@ -33,7 +33,7 @@ static std::string const pool_name = "mpi";
 
 // ------------------------------------------------------------------------
 // this is our custom scheduler type
-using numa_scheduler = pika::threads::shared_priority_queue_scheduler<>;
+using numa_scheduler = pika::threads::detail::shared_priority_queue_scheduler<>;
 using namespace pika::threads;
 
 // ------------------------------------------------------------------------
@@ -44,8 +44,7 @@ void do_stuff(std::size_t n, bool printout)
         std::cout << "[do stuff] " << n << "\n";
     for (std::size_t i(0); i < n; ++i)
     {
-        double f = std::sin(
-            2 * M_PI * static_cast<double>(i) / static_cast<double>(n));
+        double f = std::sin(2 * M_PI * static_cast<double>(i) / static_cast<double>(n));
         if (printout)
             std::cout << "sin(" << i << ") = " << f << ", ";
     }
@@ -65,8 +64,7 @@ int pika_main(pika::program_options::variables_map&)
 
     // create an executor with high priority for important tasks
     pika::execution::parallel_executor high_priority_executor(
-        pika::this_thread::get_pool(),
-        pika::execution::thread_priority::critical);
+        pika::this_thread::get_pool(), pika::execution::thread_priority::critical);
     pika::execution::parallel_executor normal_priority_executor;
 
     pika::execution::parallel_executor pool_executor;
@@ -74,8 +72,7 @@ int pika_main(pika::program_options::variables_map&)
     if (use_pools)
     {
         // get executors
-        pika::execution::parallel_executor mpi_exec(
-            &pika::resource::get_thread_pool(pool_name));
+        pika::execution::parallel_executor mpi_exec(&pika::resource::get_thread_pool(pool_name));
         pool_executor = mpi_exec;
         std::cout << "\n[pika_main] got mpi executor " << std::endl;
     }
@@ -98,27 +95,23 @@ int pika_main(pika::program_options::variables_map&)
     print_system_characteristics();
 
     // use executor to schedule work on custom pool
-    pika::future<void> future_1 =
-        pika::async(pool_executor, &do_stuff, 5, true);
+    pika::future<void> future_1 = pika::async(pool_executor, &do_stuff, 5, true);
 
-    pika::future<void> future_2 = future_1.then(
-        pool_executor, [](pika::future<void>&&) { do_stuff(5, true); });
+    pika::future<void> future_2 =
+        future_1.then(pool_executor, [](pika::future<void>&&) { do_stuff(5, true); });
 
     pika::future<void> future_3 = future_2.then(pool_executor,
-        [pool_executor, high_priority_executor, async_count](
-            pika::future<void>&&) mutable {
+        [pool_executor, high_priority_executor, async_count](pika::future<void>&&) mutable {
             pika::future<void> future_4, future_5;
             for (std::size_t i = 0; i < async_count; i++)
             {
                 if (i % 2 == 0)
                 {
-                    future_4 = pika::async(
-                        pool_executor, &do_stuff, async_count, false);
+                    future_4 = pika::async(pool_executor, &do_stuff, async_count, false);
                 }
                 else
                 {
-                    future_5 = pika::async(
-                        high_priority_executor, &do_stuff, async_count, false);
+                    future_5 = pika::async(high_priority_executor, &do_stuff, async_count, false);
                 }
             }
             // the last futures we made are stored in here
@@ -141,16 +134,14 @@ int pika_main(pika::program_options::variables_map&)
             std::lock_guard<pika::mutex> lock(m);
             if (thread_set.insert(std::this_thread::get_id()).second)
             {
-                std::cout << std::hex << pika::this_thread::get_id() << " "
-                          << std::hex << std::this_thread::get_id()
-                          << " high priority executor i " << std::dec << i
-                          << std::endl;
+                std::cout << std::hex << pika::this_thread::get_id() << " " << std::hex
+                          << std::this_thread::get_id() << " high priority executor i " << std::dec
+                          << i << std::endl;
             }
         }));
     }
     pika::wait_all(std::move(futures));
-    std::cout << "thread set contains " << std::dec << thread_set.size()
-              << std::endl;
+    std::cout << "thread set contains " << std::dec << thread_set.size() << std::endl;
     futures.clear();
     thread_set.clear();
 
@@ -161,16 +152,14 @@ int pika_main(pika::program_options::variables_map&)
             std::lock_guard<pika::mutex> lock(m);
             if (thread_set.insert(std::this_thread::get_id()).second)
             {
-                std::cout << std::hex << pika::this_thread::get_id() << " "
-                          << std::hex << std::this_thread::get_id()
-                          << " normal priority executor i " << std::dec << i
-                          << std::endl;
+                std::cout << std::hex << pika::this_thread::get_id() << " " << std::hex
+                          << std::this_thread::get_id() << " normal priority executor i "
+                          << std::dec << i << std::endl;
             }
         }));
     }
     pika::wait_all(std::move(futures));
-    std::cout << "thread set contains " << std::dec << thread_set.size()
-              << std::endl;
+    std::cout << "thread set contains " << std::dec << thread_set.size() << std::endl;
     futures.clear();
     thread_set.clear();
 
@@ -181,15 +170,14 @@ int pika_main(pika::program_options::variables_map&)
             std::lock_guard<pika::mutex> lock(m);
             if (thread_set.insert(std::this_thread::get_id()).second)
             {
-                std::cout << std::hex << pika::this_thread::get_id() << " "
-                          << std::hex << std::this_thread::get_id()
-                          << " pool executor i " << std::dec << i << std::endl;
+                std::cout << std::hex << pika::this_thread::get_id() << " " << std::hex
+                          << std::this_thread::get_id() << " pool executor i " << std::dec << i
+                          << std::endl;
             }
         }));
     }
     pika::wait_all(std::move(futures));
-    std::cout << "thread set contains " << std::dec << thread_set.size()
-              << std::endl;
+    std::cout << "thread set contains " << std::dec << thread_set.size() << std::endl;
     futures.clear();
     thread_set.clear();
 
@@ -197,8 +185,8 @@ int pika_main(pika::program_options::variables_map&)
 }
 
 // -------------------------------------------------------------------------
-void init_resource_partitioner_handler(pika::resource::partitioner& rp,
-    pika::program_options::variables_map const& vm)
+void init_resource_partitioner_handler(
+    pika::resource::partitioner& rp, pika::program_options::variables_map const& vm)
 {
     use_pools = vm.count("use-pools") != 0;
     pool_threads = vm["pool-threads"].as<int>();
@@ -212,8 +200,7 @@ void init_resource_partitioner_handler(pika::resource::partitioner& rp,
         // we use unspecified as the scheduler type and it will be set according to
         // the --pika:queuing=xxx option or default.
         auto deft = ::pika::threads::scheduler_mode::default_mode;
-        rp.create_thread_pool(pool_name,
-            pika::resource::scheduling_policy::shared_priority, deft);
+        rp.create_thread_pool(pool_name, pika::resource::scheduling_policy::shared_priority, deft);
         // add N pus to network pool
         int count = 0;
         for (pika::resource::numa_domain const& d : rp.numa_domains())
@@ -224,16 +211,14 @@ void init_resource_partitioner_handler(pika::resource::partitioner& rp,
                 {
                     if (count < pool_threads)
                     {
-                        std::cout << "Added pu " << count++ << " to pool \""
-                                  << pool_name << "\"\n";
+                        std::cout << "Added pu " << count++ << " to pool \"" << pool_name << "\"\n";
                         rp.add_resource(p, pool_name);
                     }
                 }
             }
         }
 
-        rp.create_thread_pool(
-            "default", pika::resource::scheduling_policy::unspecified, deft);
+        rp.create_thread_pool("default", pika::resource::scheduling_policy::unspecified, deft);
     }
 }
 
