@@ -8,18 +8,18 @@
 #include <pika/config.hpp>
 #include <pika/schedulers/deadlock_detection.hpp>
 
-namespace pika::threads {
-#ifdef PIKA_HAVE_THREAD_MINIMAL_DEADLOCK_DETECTION
-    static bool minimal_deadlock_detection_enabled = false;
+namespace pika::threads::detail {
+#ifdef PIKA_HAVE_THREAD_DEADLOCK_DETECTION
+    static bool deadlock_detection_enabled = false;
 
-    void set_minimal_deadlock_detection_enabled(bool enabled)
+    void set_deadlock_detection_enabled(bool enabled)
     {
-        minimal_deadlock_detection_enabled = enabled;
+        deadlock_detection_enabled = enabled;
     }
 
-    bool get_minimal_deadlock_detection_enabled()
+    bool get_deadlock_detection_enabled()
     {
-        return minimal_deadlock_detection_enabled;
+        return deadlock_detection_enabled;
     }
 #endif
-}    // namespace pika::threads
+}    // namespace pika::threads::detail
