@@ -12,7 +12,6 @@
 #include <pika/modules/memory.hpp>
 #include <pika/synchronization/detail/condition_variable.hpp>
 #include <pika/synchronization/no_mutex.hpp>
-#include <pika/synchronization/spinlock.hpp>
 #include <pika/thread_support/unlock_guard.hpp>
 #include <pika/threading_base/thread_helpers.hpp>
 #include <pika/timing/steady_clock.hpp>
@@ -101,6 +100,7 @@ namespace pika::detail {
         // swap the list
         queue_type queue;
         queue.swap(queue_);
+        lock.unlock();
 
         if (!queue.empty())
         {
@@ -118,6 +118,7 @@ namespace pika::detail {
 
                 if (PIKA_UNLIKELY(!ctx))
                 {
+                    lock.lock();
                     prepend_entries(lock, queue);
                     lock.unlock();
 
@@ -126,8 +127,6 @@ namespace pika::detail {
                     return;
                 }
 
-                [[maybe_unused]] util::ignore_while_checking il(&lock);
-
                 ctx.resume();
 
             } while (!queue.empty());
