@@ -16,22 +16,18 @@
 namespace pika::detail {
 
     template <typename DestType, typename Config,
-        std::enable_if_t<!std::is_same<DestType, std::string>::value, bool> =
-            false>
-    DestType get_entry_as(
-        Config const& config, std::string const& key, DestType const& dflt)
+        std::enable_if_t<!std::is_same<DestType, std::string>::value, bool> = false>
+    DestType get_entry_as(Config const& config, std::string const& key, DestType const& dflt)
     {
         std::string const& entry = config.get_entry(key, "");
         if (entry.empty())
             return dflt;
-        return util::from_string<DestType>(entry, dflt);
+        return detail::from_string<DestType>(entry, dflt);
     }
 
     template <typename DestType, typename Config,
-        std::enable_if_t<std::is_same<DestType, std::string>::value, bool> =
-            false>
-    DestType get_entry_as(
-        Config const& config, std::string const& key, DestType const& dflt)
+        std::enable_if_t<std::is_same<DestType, std::string>::value, bool> = false>
+    DestType get_entry_as(Config const& config, std::string const& key, DestType const& dflt)
     {
         return config.get_entry(key, dflt);
     }
